//
//  InterfaceController.swift
//  WCDemo WatchKit Extension
//
//  Created by Felix Lisczyk on 17.04.16.
//  Copyright © 2016 Felix Lisczyk. All rights reserved.
//

import WatchKit
import Foundation
import WatchConnectivity


class InterfaceController: WKInterfaceController, WCSessionDelegate {

    @IBOutlet var counterLabel: WKInterfaceLabel!
    @IBOutlet var dateLabel: WKInterfaceLabel!
    
    private lazy var dateFormatter: NSDateFormatter = {
        let dateFormatter = NSDateFormatter()
        dateFormatter.dateStyle = .ShortStyle
        dateFormatter.timeStyle = .MediumStyle
        return dateFormatter
    }()
    
    private var counter = 0
    private var latestDate: NSDate?
    
    override func awakeWithContext(context: AnyObject?) {
        super.awakeWithContext(context)
        
        // Configure interface objects here.
        
        if WCSession.isSupported() {
            let session = WCSession.defaultSession()
            session.delegate = self
            session.activateSession()
        }
    }

    override func willActivate() {
        // This method is called when watch view controller is about to be visible to user
        super.willActivate()
        counterLabel.setText(String(counter))
        if let latestDate = latestDate {
            dateLabel.setText(dateFormatter.stringFromDate(latestDate))
        }
    }

    override func didDeactivate() {
        // This method is called when watch view controller is no longer visible
        super.didDeactivate()
    }
    
    //MARK: WCSessionDelegate
    
    func session(session: WCSession, didReceiveUserInfo userInfo: [String : AnyObject]) {
        if let messageDate = userInfo["IncrementWithDate"] as? NSDate {
            counter = counter + 1
            counterLabel.setText(String(counter))
            
            latestDate = messageDate
            dateLabel.setText(dateFormatter.stringFromDate(messageDate))
        }
    }
    
    func session(session: WCSession, activationDidCompleteWithState activationState: WCSessionActivationState, error: NSError?) {
        if let error = error {
            NSLog(error.localizedDescription)
        }
    }
}
